@@ -1,5 +1,7 @@
+import sys
 import os
 import logging
+sys.path.insert(0, os.getcwd())
 
 # from sachima.log import logger
 
